Datasets
=====================================
.. currentmodule:: kooplearn.datasets

.. autoclass:: kooplearn.datasets.LogisticMap
    :members:

.. autoclass:: kooplearn.datasets.DuffingOscillator
    :members:

.. autoclass:: kooplearn.datasets.Lorenz63
    :members:

.. footbibliography::